@@ -14,7 +14,7 @@ class Extract(Step.Step):
         self.preStep = ""
 
     def startup(self):
-        super(self).startup()
+        super(Extract,self).startup()
 
     
     def doWorkAndHandoff(self):
