@@ -16,7 +16,7 @@ class Ml(Step.Step):
         self.preStep= "Tr"
 
     def startup(self):
-        super(self).startup()
+        super(Ml,self).startup()
         self.startSubscriber()
 
     def doWorkAndHandoff(self):
