@@ -21,8 +21,7 @@ class Step:
         self.step = "St"
         self.paramsFile = 'Step.properties'
         self.logger = 'logStep'
-        self.logFile = self.getRelativeFile( os.getcwd() +'\../logs/Step.log')
-        self.preStep= "St"
+        self.logFile = self.getRelativeFile('../logs/Step.log')
 
     # Needed for relative paths
     def getRelativeFile(self, filename):
@@ -35,7 +34,9 @@ class Step:
         self.setTaskID()
         self.setUUID()
         self.params = self.trimPropertiesConfig(self.loadParams(self.paramsFile))
-        self.nextStep = self.params["nextStep"].data
+        self.nextStep = None
+        if self.params["nextStep"]:
+            self.nextStep = self.params["nextStep"].data
         self.setTaskExecutionID()
         self.startRedisConn()
         self.setLogger(self.logger, self.logFile, logging.INFO)
@@ -54,7 +55,6 @@ class Step:
     def setTaskExecutionID(self):
         self.taskExecutionID = self.taskID + "_" + self.startTime
 
-
     # Get the NodeId of the System. Similar to uname -n
     def getNodeId(self):
         return platform.node()
@@ -66,7 +66,7 @@ class Step:
     # Load parameters from file
     def loadParams(self, filename):
         configs = Properties()
-        filename = self.getRelativeFile(os.getcwd() + '\../params/' + filename)
+        filename = self.getRelativeFile('../params/' + filename)
         with open(filename, 'rb') as config_file:
             configs.load(config_file)
             config_file.close()
@@ -78,10 +78,6 @@ class Step:
         for properties in config:
             trimmedPropertiesFile[properties.strip()] = config[properties].data.strip()
         return trimmedPropertiesFile
-    
-    def startSubscriber(self):
-        self.subscriber = self.rC.pubsub()
-        self.subscriber.subscribe(self.taskID + "_" + self.preStep)
 
     # declaring Redis connection parameters
     def makeRedisConn(self):
@@ -95,6 +91,12 @@ class Step:
         except (redis.exceptions.ConnectionError, ConnectionRefusedError):
             self.logError(self.step, 'Error in redis connection setup')
 
+    # This method has to be used by the relevant class - Transform, ML, Load to listen to their queue.
+    def startSubscriber(self):
+        self.subscriber = self.rC.pubsub()
+        self.subscriber.subscribe(self.taskID + "_" + self.step)
+
+
     # Extracting UUID from path of current working directory
     def setUUID(self):
         path = os.getcwd().replace("\\", "/").split("/")
@@ -102,16 +104,19 @@ class Step:
 
     # Reading taskID from text file
     def setTaskID(self):
-        with open(self.getRelativeFile( os.getcwd() +'\../params/Identifier.txt')) as f:
+        with open(self.getRelativeFile('../params/Identifier.txt')) as f:
             lines = f.readlines()
         self.taskID = lines[0]
         f.close()
 
     # Storing the dataToHandoff in a dataframe and the converting  DF to json and printing it
-    # def handOff(self, rC, taskID, step, dataToHandoff):
-    def handOff(self, step, dataToHandoff):
-        df = pd.DataFrame(eval(dataToHandoff))
-        self.rC.publish(self.taskID + "_" + step, df.to_json())
+    # def handOff(self, rC, taskID, nextStep, dataToHandoff):
+    def handOff(self, dataToHandoff):
+        try:
+            self.logInfo("Handoff",self.taskID)
+            self.rC.publish(self.taskID + "_" + self.nextStep, dataToHandoff)
+        except(ConnectionError) as cE:
+            self.logError(self.nextStep, str(cE))
 
     # setter function to configure Logger
     def setLogger(self, logger_name, log_file, level=logging.INFO):
@@ -151,7 +156,6 @@ class Step:
             stack_trace = list()
             for trace in trace_back:
                 stack_trace.append("File : %s , Line : %d, Message : %s" % (trace[0], trace[1], trace[3]))
-            # self.getLogger().error(self.logMessageFormat(self.step, inspect.stack()[0][3], str(str(ex_traceback) + ' ' + str(stack_trace))))
             return str(str(ex_traceback) + ' ' + str(stack_trace))
         except Exception as error:
             print('#######exceptionTraceback#### ' + str(error))
@@ -215,5 +219,3 @@ class Step:
         currentframe = inspect.currentframe()
         outerFrames = inspect.getouterframes(currentframe, 2)
         self.getLogger().fatal(self.logMessageFormat(step, outerFrames, message))
-
-        
